/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.core.container.ri.servlet;

import java.util.Locale;

/**
 * Gets thrown when the {@code ServletContext} for the current thread of
 * execution is {@code null}.
 *
 * @author <a href="mailto:cs@schulte.it">Christian Schulte</a>
 * @version $Id: ContextLostException.java 3217 2007-04-30 00:47:30Z schulte2005 $
 */
public class ContextLostException extends IllegalStateException
{
    //--Constructors------------------------------------------------------------

    /**
     * Creates a new instance of {@code ContextLostException} taking
     * the {@code Thread} trying to access the context.
     *
     * @param thread the {@code Thread} accessing the context.
     */
    public ContextLostException(final Thread thread)
    {
        super(ContextLostExceptionBundle.
            getContextLostMessage(Locale.getDefault()).
            format(new Object[] { thread != null ? thread.getName() : null }));

        this.thread = thread;
    }

    //------------------------------------------------------------Constructors--
    //--ContextLostException----------------------------------------------------

    /***
     * The thread accessing the context.
     * @serial
     */
    private Thread thread;

    /**
     * Gets the thread accessing the context.
     *
     * @return the thread accessing the context or {@code null}.
     */
    public Thread getThread()
    {
        return this.thread;
    }

    //----------------------------------------------------ContextLostException--
}
